from enum import Enum
from ...types import MCEnum, UnsignedByte, Byte, String, SafeBuff
from ...world import BlockMeta


class Mob(MCEnum):

    IntegerType: UnsignedByte

    MOB = 48
    MONSTER = 49
    CREEPER = 50
    SKELETON = 51
    SPIDER = 52
    GIANT_ZOMBIE = 53
    ZOMBIE = 54
    SLIME = 55
    GHAST = 56
    ZOMBIE_PIGMAN = 57
    ENDERMAN = 58
    CAVE_SPIDER = 59
    SILVERFISH = 60
    BLAZE = 61
    MAGMA_CUBE = 62
    ENDER_DRAGON = 63
    WITHER = 64
    BAT = 65
    WITCH = 66
    ENDERMITE = 67
    GUARDIAN = 68
    SHULKER = 69
    PIG = 90
    SHEEP = 91
    COW = 92
    CHICKEN = 93
    SQUID = 94
    WOLF = 95
    MOOSHROOM = 96
    SNOWMAN = 97
    OCELOT = 98
    IRON_GOLEM = 99
    HORSE = 100
    RABBIT = 101
    VILLAGER = 120

class Object(MCEnum):

    IntegerType: Byte

    BOAT = 1
    ITEM_STACK = 2 # (SLOT)
    AREA_EFFECT_CLOUD = 3
    MINECART = 10
    MINECART_STORAGE = 11 # (unused since 1.6.x)
    MINECART_POWERED = 12 # (unused since 1.6.x)
    ACTIVATED_TNT = 50
    ENDERCRYSTAL = 51
    ARROW = 60 # (PROJECTILE)
    SNOWBALL = 61 # (PROJECTILE)
    EGG = 62 # (PROJECTILE)
    FIREBALL = 63 # (GHAST PROJECTILE)
    FIRECHARGE = 64 # (BLAZE PROJECTILE)
    THROWN_ENDERPEARL = 65
    WITHER_SKULL = 66 # (PROJECTILE)
    SHULKER_BULLET = 67
    FALLING_OBJECT = 70
    ITEM_FRAME = 71
    EYE_OF_ENDER = 72
    THROWN_POTION = 73
    FALLING_DRAGON_EGG = 74
    THROWN_EXP_BOTTLE = 75
    FIREWORK_ROCKET = 76
    LEASH_KNOT = 77
    ARMORSTAND = 78
    FISHING_FLOAT = 90
    SPECTRAL_ARROW = 91
    TIPPED_ARROW = 92
    DRAGON_FIREBALL = 93

class Sound(Enum):

    def to_id(self) -> str:
        return self.name.lower().replace("_", ".")
    
    @classmethod
    def from_id(cls, id: str) -> None:
        return getattr(cls, id.upper().replace(".", "_"))
    
    def build(self) -> bytes:
        return String.build(self.to_id())
    
    @classmethod
    def destroy(cls, buff: SafeBuff) -> None:
        id_ = String.destroy(buff)
        return cls.from_id(id_)

    AMBIENT_CAVE_CAVE = 0
    AMBIENT_WEATHER_RAIN = 1
    AMBIENT_WEATHER_THUNDER = 2
    DAMAGE_FALLBIG = 3
    DAMAGE_FALLSMALL = 4
    FIRE_FIRE = 5
    FIRE_IGNITE = 6
    LIQUID_LAVA = 7
    LIQUID_LAVAPOP = 8
    LIQUID_SPLASH = 9
    LIQUID_WATER = 10
    MOB_BLAZE_BREATHE = 11
    MOB_BLAZE_DEATH = 12
    MOB_BLAZE_HIT = 13
    MOB_CAT_HISS = 14
    MOB_CAT_HITT = 15
    MOB_CAT_MEOW = 16
    MOB_CAT_PURR = 17
    MOB_CAT_PURREOW = 18
    MOB_CHICKEN_HURT = 19
    MOB_CHICKEN_PLOP = 20
    MOB_COW_HURT = 21
    MOB_CREEPER = 22
    MOB_CREEPERDEATH = 23
    MOB_ENDERMEN_DEATH = 24
    MOB_ENDERMEN_HIT = 25
    MOB_ENDERMEN_IDLE = 26
    MOB_ENDERMEN_PORTAL = 27
    MOB_ENDERMEN_SCREAM = 28
    MOB_ENDERMEN_STARE = 29
    MOB_GHAST_AFFECTIONATESCREAM = 30
    MOB_GHAST_CHARGE = 31
    MOB_GHAST_DEATH = 32
    MOB_GHAST_FIREBALL = 33
    MOB_GHAST_MOAN = 34
    MOB_GHAST_SCREAM = 35
    MOB_IRONGOLEM_DEATH = 36
    MOB_IRONGOLEM_HIT = 37
    MOB_IRONGOLEM_THROW = 38
    MOB_IRONGOLEM_WALK = 39
    MOB_MAGMACUBE_BIG = 40
    MOB_MAGMACUBE_JUMP = 41
    MOB_MAGMACUBE_SMALL = 42
    MOB_PIG_DEATH = 43
    MOB_SILVERFISH_HIT = 44
    MOB_SILVERFISH_KILL = 45
    MOB_SILVERFISH_SAY = 46
    MOB_SILVERFISH_STEP = 47
    MOB_SKELETON_DEATH = 48
    MOB_SKELETON_HURT = 49
    MOB_SLIME_ATTACK = 50
    MOB_SPIDER_DEATH = 51
    MOB_WOLF_BARK = 52
    MOB_WOLF_DEATH = 53
    MOB_WOLF_GROWL = 54
    MOB_WOLF_HOWL = 55
    MOB_WOLF_HURT = 56
    MOB_WOLF_PANTING = 57
    MOB_WOLF_SHAKE = 58
    MOB_WOLF_WHINE = 59
    MOB_ZOMBIE_METAL = 60
    MOB_ZOMBIE_WOOD = 61
    MOB_ZOMBIE_WOODBREAK = 62
    MOB_ZOMBIE = 63
    MOB_ZOMBIE_DEATH = 64
    MOB_ZOMBIE_HURT = 65
    MOB_ZOMBIEPIG_ZPIG = 66
    MOB_ZOMBIEPIG_ZPIGANGRY = 67
    MOB_ZOMBIEPIG_ZPIGDEATH = 68
    MOB_ZOMBIEPIG_ZPIGHURT = 69
    NOTE_BASS = 70
    NOTE_BASSATTACK = 71
    NOTE_BD = 72
    NOTE_HARP = 73
    NOTE_HAT = 74
    NOTE_PLING = 75
    NOTE_SNARE = 76
    PORTAL_PORTAL = 77
    PORTAL_TRAVEL = 78
    PORTAL_TRIGGER = 79
    RANDOM_BOW = 80
    RANDOM_BOWHIT = 81
    RANDOM_BREAK = 82
    RANDOM_BREATH = 83
    RANDOM_BURP = 84
    RANDOM_CHESTCLOSED = 85
    RANDOM_CHESTOPEN = 86
    RANDOM_CLICK = 87
    RANDOM_DOOR_CLOSE = 88
    RANDOM_DOOR_OPEN = 89
    RANDOM_DRINK = 90
    RANDOM_EAT = 91
    RANDOM_EXPLODE = 92
    RANDOM_FIZZ = 93
    RANDOM_FUSE = 94
    RANDOM_GLASS = 95
    RANDOM_LEVELUP = 96
    RANDOM_OLD_EXPLODE = 97
    RANDOM_ORB = 98
    RANDOM_POP = 99
    RANDOM_SPLASH = 100
    RANDOM_WOODCLICK = 101
    STEP_CLOTH = 102
    STEP_GRASS = 103
    STEP_GRAVEL = 104
    STEP_SAND = 105
    STEP_SNOW = 106
    STEP_STONE = 107
    STEP_WOOD = 108
    TILE_PISTON_IN = 109
    TILE_PISTON_OUT = 110
    DAMAGE_HIT = 111
    DIG_CLOTH = 112
    DIG_GRASS = 113
    DIG_GRAVEL = 114
    DIG_SAND = 115
    DIG_SNOW = 116
    DIG_STONE = 117
    DIG_WOOD = 118
    LIQUID_SWIM = 119
    MINECART_BASE = 120
    MINECART_INSIDE = 121
    MOB_CHICKEN_SAY = 122
    MOB_CHICKEN_STEP = 123
    MOB_COW_SAY = 124
    MOB_COW_STEP = 125
    MOB_CREEPER_SAY = 126
    MOB_PIG_DEATH2 = 127
    MOB_PIG_SAY = 128
    MOB_PIG_STEP = 129
    MOB_SHEEP_SAY = 130
    MOB_SHEEP_SHEAR = 131
    MOB_SHEEP_STEP = 132
    MOB_SKELETON_SAY = 133
    MOB_SKELETON_STEP = 134
    MOB_SLIME_ATTACK2 = 135
    MOB_SLIME_BIG = 136
    MOB_SLIME_SMALL = 137
    MOB_SPIDER_SAY = 138
    MOB_SPIDER_STEP = 139
    MOB_WOLF_STEP = 140
    MOB_ZOMBIE_DEATH2 = 141
    MOB_ZOMBIE_HURT2 = 142
    MOB_ZOMBIE_SAY = 143
    MOB_ZOMBIE_STEP = 144
    RANDOM_CLASSIC_HURT = 145
    STEP_LADDER = 146
    MOB_BAT_DEATH = 147
    MOB_BAT_HURT = 148
    MOB_BAT_IDLE = 149
    MOB_BAT_TAKEOFF = 150
    MOB_ENDERDRAGON_END = 151
    MOB_ENDERDRAGON_GROWL = 152
    MOB_ENDERDRAGON_HIT = 153
    MOB_ENDERDRAGON_WINGS = 154
    MOB_WITHER_DEATH = 155
    MOB_WITHER_HURT = 156
    MOB_WITHER_IDLE = 157
    MOB_WITHER_SHOOT = 158
    MOB_WITHER_SPAWN = 159
    MOB_ZOMBIE_INFECT = 160
    MOB_ZOMBIE_REMEDY = 161
    MOB_ZOMBIE_UNFECT = 162
    RANDOM_ANVIL_BREAK = 163
    RANDOM_ANVIL_LAND = 164
    RANDOM_ANVIL_USE = 165
    GAME_NEUTRAL_SWIM_SPLASH = 166

class Biome(int, Enum):
    OCEAN = 0
    PLAINS = 1
    DESERT = 2
    EXTREME_HILLS = 3
    FOREST = 4
    TAIGA = 5
    SWAMPLAND = 6
    RIVER = 7
    HELL = 8
    SKY = 9
    FROZEN_OCEAN = 10
    FROZEN_RIVER = 11
    ICE_FLATS = 12
    ICE_MOUNTAINS = 13
    MUSHROOM_ISLAND = 14
    MUSHROOM_ISLAND_SHORE = 15
    BEACHES = 16
    DESERT_HILLS = 17
    FOREST_HILLS = 18
    TAIGA_HILLS = 19
    SMALLER_EXTREME_HILLS = 20
    JUNGLE = 21
    JUNGLE_HILLS = 22
    JUNGLE_EDGE = 23
    DEEP_OCEAN = 24
    STONE_BEACH = 25
    COLD_BEACH = 26
    BIRCH_FOREST = 27
    BIRCH_FOREST_HILLS = 28
    ROOFED_FOREST = 29
    TAIGA_COLD = 30
    TAIGA_COLD_HILLS = 31
    REDWOOD_TAIGA = 32
    REDWOOD_TAIGA_HILLS = 33
    EXTREME_HILLS_WITH_TREES = 34
    SAVANNA = 35
    SAVANNA_ROCK = 36
    MESA = 37
    MESA_ROCK = 38
    MESA_CLEAR_ROCK = 39
    VOID = 127
    MUTATED_PLAINS = 129
    MUTATED_DESERT = 130
    MUTATED_EXTREME_HILLS = 131
    MUTATED_FOREST = 132
    MUTATED_TAIGA = 133
    MUTATED_SWAMPLAND = 134
    MUTATED_ICE_FLATS = 140
    MUTATED_JUNGLE = 149
    MUTATED_JUNGLE_EDGE = 151
    MUTATED_BIRCH_FOREST = 155
    MUTATED_BIRCH_FOREST_HILLS = 156
    MUTATED_ROOFED_FOREST = 157
    MUTATED_TAIGA_COLD = 158
    MUTATED_REDWOOD_TAIGA = 160
    MUTATED_REDWOOD_TAIGA_HILLS = 161
    MUTATED_EXTREME_HILLS_WITH_TREES = 162
    MUTATED_SAVANNA = 163
    MUTATED_SAVANNA_ROCK = 164
    MUTATED_MESA = 165
    MUTATED_MESA_ROCK = 166
    MUTATED_MESA_CLEAR_ROCK = 167

class Material(BlockMeta, Enum):
    __proto__ = 47

    AIR = 'Air', 0, 0, 'air'
    STONE = 'Stone', 1, 0, 'stone'
    GRANITE = 'Granite', 1, 1, 'stone:1'
    POLISHED_GRANITE = 'Polished granite', 1, 2, 'stone:2'
    DIORITE = 'Diorite', 1, 3, 'stone:3'
    POLISHED_DIORITE = 'Polished diorite', 1, 4, 'stone:4'
    ANDESITE = 'Andesite', 1, 5, 'stone:5'
    POLISHED_ANDESITE = 'Polished andesite', 1, 6, 'stone:6'
    GRASS = 'Grass', 2, 0, 'grass'
    DIRT = 'Dirt', 3, 0, 'dirt'
    COARSE_DIRT = 'Coarse dirt', 3, 1, 'dirt:1'
    PODZOL = 'Podzol', 3, 2, 'dirt:2'
    COBBLESTONE = 'Cobblestone', 4, 0, 'cobblestone'
    WOODEN_PLANK_OAK = 'Wooden plank (oak)', 5, 0, 'planks'
    WOODEN_PLANK_SPRUCE = 'Wooden plank (spruce)', 5, 1, 'planks:1'
    WOODEN_PLANK_BIRCH = 'Wooden plank (birch)', 5, 2, 'planks:2'
    WOODEN_PLANK_JUNGLE = 'Wooden plank (jungle)', 5, 3, 'planks:3'
    WOODEN_PLANK_ACACIA = 'Wooden plank (acacia)', 5, 4, 'planks:4'
    WOODEN_PLANK_DARK_OAK = 'Wooden plank (dark oak)', 5, 5, 'planks:5'
    SAPLING_OAK = 'Sapling (oak)', 6, 0, 'sapling'
    SAPLING_SPRUCE = 'Sapling (spruce)', 6, 1, 'sapling:1'
    SAPLING_BIRCH = 'Sapling (birch)', 6, 2, 'sapling:2'
    SAPLING_JUNGLE = 'Sapling (jungle)', 6, 3, 'sapling:3'
    SAPLING_ACACIA = 'Sapling (acacia)', 6, 4, 'sapling:4'
    SAPLING_DARK_OAK = 'Sapling (dark oak)', 6, 5, 'sapling:5'
    BEDROCK = 'Bedrock', 7, 0, 'bedrock'
    WATER = 'Water', 8, 0, 'flowing_water'
    WATER_NO_SPREAD = 'Water (no spread)', 9, 0, 'water'
    LAVA = 'Lava', 10, 0, 'flowing_lava'
    LAVA_NO_SPREAD = 'Lava (no spread)', 11, 0, 'lava'
    SAND = 'Sand', 12, 0, 'sand'
    RED_SAND = 'Red sand', 12, 1, 'sand:1'
    GRAVEL = 'Gravel', 13, 0, 'gravel'
    GOLD_ORE = 'Gold ore', 14, 0, 'gold_ore'
    IRON_ORE = 'Iron ore', 15, 0, 'iron_ore'
    COAL_ORE = 'Coal ore', 16, 0, 'coal_ore'
    WOOD_OAK = 'Wood (oak)', 17, 0, 'log'
    WOOD_SPRUCE = 'Wood (spruce)', 17, 1, 'log:1'
    WOOD_BIRCH = 'Wood (birch)', 17, 2, 'log:2'
    WOOD_JUNGLE = 'Wood (jungle)', 17, 3, 'log:3'
    WOOD_OAK_4 = 'Wood (oak 4)', 17, 4, 'log:4'
    WOOD_OAK_5 = 'Wood (oak 5)', 17, 5, 'log:5'
    LEAVES_OAK = 'Leaves (oak)', 18, 0, 'leaves'
    LEAVES_SPRUCE = 'Leaves (spruce)', 18, 1, 'leaves:1'
    LEAVES_BIRCH = 'Leaves (birch)', 18, 2, 'leaves:2'
    LEAVES_JUNGLE = 'Leaves (jungle)', 18, 3, 'leaves:3'
    SPONGE = 'Sponge', 19, 0, 'sponge'
    WET_SPONGE = 'Wet sponge', 19, 1, 'sponge:1'
    GLASS = 'Glass', 20, 0, 'glass'
    LAPIS_LAZULI_ORE = 'Lapis lazuli ore', 21, 0, 'lapis_ore'
    LAPIS_LAZULI_BLOCK = 'Lapis lazuli block', 22, 0, 'lapis_block'
    DISPENSER = 'Dispenser', 23, 0, 'dispenser'
    SANDSTONE = 'Sandstone', 24, 0, 'sandstone'
    SANDSTONE_CHISELED = 'Sandstone (chiseled)', 24, 1, 'sandstone:1'
    SANDSTONE_SMOOTH = 'Sandstone (smooth)', 24, 2, 'sandstone:2'
    NOTE_BLOCK = 'Note block', 25, 0, 'noteblock'
    BED_BLOCK = 'Bed (block)', 26, 0, 'bed'
    RAIL_POWERED = 'Rail (powered)', 27, 0, 'golden_rail'
    RAIL_DETECTOR = 'Rail (detector)', 28, 0, 'detector_rail'
    STICKY_PISTON = 'Sticky piston', 29, 0, 'sticky_piston'
    COBWEB = 'Cobweb', 30, 0, 'web'
    TALL_GRASS_DEAD_SHRUB = 'Tall grass (dead shrub)', 31, 0, 'tallgrass'
    TALL_GRASS = 'Tall grass', 31, 1, 'tallgrass:1'
    TALL_GRASS_FERN = 'Tall grass (fern)', 31, 2, 'tallgrass:2'
    DEAD_SHRUB = 'Dead shrub', 32, 0, 'deadbush'
    PISTON = 'Piston', 33, 0, 'piston'
    PISTON_HEAD = 'Piston (head)', 34, 0, 'piston_head'
    WOOL = 'Wool', 35, 0, 'wool'
    ORANGE_WOOL = 'Orange wool', 35, 1, 'wool:1'
    MAGENTA_WOOL = 'Magenta wool', 35, 2, 'wool:2'
    LIGHT_BLUE_WOOL = 'Light blue wool', 35, 3, 'wool:3'
    YELLOW_WOOL = 'Yellow wool', 35, 4, 'wool:4'
    LIME_WOOL = 'Lime wool', 35, 5, 'wool:5'
    PINK_WOOL = 'Pink wool', 35, 6, 'wool:6'
    GRAY_WOOL = 'Gray wool', 35, 7, 'wool:7'
    LIGHT_GRAY_WOOL = 'Light gray wool', 35, 8, 'wool:8'
    CYAN_WOOL = 'Cyan wool', 35, 9, 'wool:9'
    PURPLE_WOOL = 'Purple wool', 35, 10, 'wool:10'
    BLUE_WOOL = 'Blue wool', 35, 11, 'wool:11'
    BROWN_WOOL = 'Brown wool', 35, 12, 'wool:12'
    GREEN_WOOL = 'Green wool', 35, 13, 'wool:13'
    RED_WOOL = 'Red wool', 35, 14, 'wool:14'
    BLACK_WOOL = 'Black wool', 35, 15, 'wool:15'
    PISTON_MOVING = 'Piston (moving)', 36, 0, 'piston_extension'
    DANDELION = 'Dandelion', 37, 0, 'yellow_flower'
    POPPY = 'Poppy', 38, 0, 'red_flower'
    BLUE_ORCHID = 'Blue orchid', 38, 1, 'red_flower:1'
    ALLIUM = 'Allium', 38, 2, 'red_flower:2'
    AZURE_BLUET = 'Azure bluet', 38, 3, 'red_flower:3'
    RED_TULIP = 'Red tulip', 38, 4, 'red_flower:4'
    ORANGE_TULIP = 'Orange tulip', 38, 5, 'red_flower:5'
    WHITE_TULIP = 'White tulip', 38, 6, 'red_flower:6'
    PINK_TULIP = 'Pink tulip', 38, 7, 'red_flower:7'
    OXEYE_DAISY = 'Oxeye daisy', 38, 8, 'red_flower:8'
    BROWN_MUSHROOM = 'Brown mushroom', 39, 0, 'brown_mushroom'
    RED_MUSHROOM = 'Red mushroom', 40, 0, 'red_mushroom'
    BLOCK_OF_GOLD = 'Block of gold', 41, 0, 'gold_block'
    BLOCK_OF_IRON = 'Block of iron', 42, 0, 'iron_block'
    STONE_SLAB_DOUBLE = 'Stone slab (double)', 43, 0, 'double_stone_slab'
    SANDSTONE_SLAB_DOUBLE = 'Sandstone slab (double)', 43, 1, 'double_stone_slab:1'
    WOODEN_SLAB_DOUBLE = 'Wooden slab (double)', 43, 2, 'double_stone_slab:2'
    COBBLESTONE_SLAB_DOUBLE = 'Cobblestone slab (double)', 43, 3, 'double_stone_slab:3'
    BRICK_SLAB_DOUBLE = 'Brick slab (double)', 43, 4, 'double_stone_slab:4'
    STONE_BRICK_SLAB_DOUBLE = 'Stone brick slab (double)', 43, 5, 'double_stone_slab:5'
    NETHER_BRICK_SLAB_DOUBLE = 'Nether brick slab (double)', 43, 6, 'double_stone_slab:6'
    QUARTZ_SLAB_DOUBLE = 'Quartz slab (double)', 43, 7, 'double_stone_slab:7'
    SMOOTH_STONE_SLAB_DOUBLE = 'Smooth stone slab (double)', 43, 8, 'double_stone_slab:8'
    SMOOTH_SANDSTONE_SLAB_DOUBLE = 'Smooth sandstone slab (double)', 43, 9, 'double_stone_slab:9'
    STONE_SLAB = 'Stone slab', 44, 0, 'stone_slab'
    SANDSTONE_SLAB = 'Sandstone slab', 44, 1, 'stone_slab:1'
    WOODEN_SLAB = 'Wooden slab', 44, 2, 'stone_slab:2'
    COBBLESTONE_SLAB = 'Cobblestone slab', 44, 3, 'stone_slab:3'
    BRICK_SLAB = 'Brick slab', 44, 4, 'stone_slab:4'
    STONE_BRICK_SLAB = 'Stone brick slab', 44, 5, 'stone_slab:5'
    NETHER_BRICK_SLAB = 'Nether brick slab', 44, 6, 'stone_slab:6'
    QUARTZ_SLAB = 'Quartz slab', 44, 7, 'stone_slab:7'
    BRICK = 'Brick', 45, 0, 'brick_block'
    TNT = 'Tnt', 46, 0, 'tnt'
    BOOKSHELF = 'Bookshelf', 47, 0, 'bookshelf'
    MOSS_STONE = 'Moss stone', 48, 0, 'mossy_cobblestone'
    OBSIDIAN = 'Obsidian', 49, 0, 'obsidian'
    TORCH = 'Torch', 50, 0, 'torch'
    FIRE = 'Fire', 51, 0, 'fire'
    MOB_SPAWNER = 'Mob spawner', 52, 0, 'mob_spawner'
    WOODEN_STAIRS_OAK = 'Wooden stairs (oak)', 53, 0, 'oak_stairs'
    CHEST = 'Chest', 54, 0, 'chest'
    REDSTONE_WIRE = 'Redstone wire', 55, 0, 'redstone_wire'
    DIAMOND_ORE = 'Diamond ore', 56, 0, 'diamond_ore'
    BLOCK_OF_DIAMOND = 'Block of diamond', 57, 0, 'diamond_block'
    WORKBENCH = 'Workbench', 58, 0, 'crafting_table'
    WHEAT_CROP = 'Wheat (crop)', 59, 0, 'wheat'
    FARMLAND = 'Farmland', 60, 0, 'farmland'
    FURNACE = 'Furnace', 61, 0, 'furnace'
    FURNACE_SMELTING = 'Furnace (smelting)', 62, 0, 'lit_furnace'
    SIGN_BLOCK = 'Sign (block)', 63, 0, 'standing_sign'
    WOOD_DOOR_BLOCK = 'Wood door (block)', 64, 0, 'wooden_door'
    LADDER = 'Ladder', 65, 0, 'ladder'
    RAIL = 'Rail', 66, 0, 'rail'
    COBBLESTONE_STAIRS = 'Cobblestone stairs', 67, 0, 'stone_stairs'
    SIGN_WALL_BLOCK = 'Sign (wall block)', 68, 0, 'wall_sign'
    LEVER = 'Lever', 69, 0, 'lever'
    STONE_PRESSURE_PLATE = 'Stone pressure plate', 70, 0, 'stone_pressure_plate'
    IRON_DOOR_BLOCK = 'Iron door (block)', 71, 0, 'iron_door'
    WOODEN_PRESSURE_PLATE = 'Wooden pressure plate', 72, 0, 'wooden_pressure_plate'
    REDSTONE_ORE = 'Redstone ore', 73, 0, 'redstone_ore'
    REDSTONE_ORE_GLOWING = 'Redstone ore (glowing)', 74, 0, 'lit_redstone_ore'
    REDSTONE_TORCH_OFF = 'Redstone torch (off)', 75, 0, 'unlit_redstone_torch'
    REDSTONE_TORCH = 'Redstone torch', 76, 0, 'redstone_torch'
    BUTTON_STONE = 'Button (stone)', 77, 0, 'stone_button'
    SNOW = 'Snow', 78, 0, 'snow_layer'
    ICE = 'Ice', 79, 0, 'ice'
    SNOW_BLOCK = 'Snow block', 80, 0, 'snow'
    CACTUS = 'Cactus', 81, 0, 'cactus'
    CLAY_BLOCK = 'Clay block', 82, 0, 'clay'
    SUGAR_CANE_BLOCK = 'Sugar cane (block)', 83, 0, 'reeds'
    JUKEBOX = 'Jukebox', 84, 0, 'jukebox'
    FENCE_OAK = 'Fence (oak)', 85, 0, 'fence'
    PUMPKIN = 'Pumpkin', 86, 0, 'pumpkin'
    NETHERRACK = 'Netherrack', 87, 0, 'netherrack'
    SOUL_SAND = 'Soul sand', 88, 0, 'soul_sand'
    GLOWSTONE = 'Glowstone', 89, 0, 'glowstone'
    PORTAL = 'Portal', 90, 0, 'portal'
    JACK_O_LANTERN = 'Jack-o-lantern', 91, 0, 'lit_pumpkin'
    CAKE_BLOCK = 'Cake (block)', 92, 0, 'cake'
    REDSTONE_REPEATER_BLOCK_OFF = 'Redstone repeater (block off)', 93, 0, 'unpowered_repeater'
    REDSTONE_REPEATER_BLOCK_ON = 'Redstone repeater (block on)', 94, 0, 'powered_repeater'
    STAINED_GLASS_WHITE = 'Stained glass (white)', 95, 0, 'stained_glass'
    STAINED_GLASS_ORANGE = 'Stained glass (orange)', 95, 1, 'stained_glass:1'
    STAINED_GLASS_MAGENTA = 'Stained glass (magenta)', 95, 2, 'stained_glass:2'
    STAINED_GLASS_LIGHT_BLUE = 'Stained glass (light blue)', 95, 3, 'stained_glass:3'
    STAINED_GLASS_YELLOW = 'Stained glass (yellow)', 95, 4, 'stained_glass:4'
    STAINED_GLASS_LIME = 'Stained glass (lime)', 95, 5, 'stained_glass:5'
    STAINED_GLASS_PINK = 'Stained glass (pink)', 95, 6, 'stained_glass:6'
    STAINED_GLASS_GRAY = 'Stained glass (gray)', 95, 7, 'stained_glass:7'
    STAINED_GLASS_LIGHT_GREY = 'Stained glass (light grey)', 95, 8, 'stained_glass:8'
    STAINED_GLASS_CYAN = 'Stained glass (cyan)', 95, 9, 'stained_glass:9'
    STAINED_GLASS_PURPLE = 'Stained glass (purple)', 95, 10, 'stained_glass:10'
    STAINED_GLASS_BLUE = 'Stained glass (blue)', 95, 11, 'stained_glass:11'
    STAINED_GLASS_BROWN = 'Stained glass (brown)', 95, 12, 'stained_glass:12'
    STAINED_GLASS_GREEN = 'Stained glass (green)', 95, 13, 'stained_glass:13'
    STAINED_GLASS_RED = 'Stained glass (red)', 95, 14, 'stained_glass:14'
    STAINED_GLASS_BLACK = 'Stained glass (black)', 95, 15, 'stained_glass:15'
    TRAPDOOR = 'Trapdoor', 96, 0, 'trapdoor'
    MONSTER_EGG_STONE = 'Monster egg (stone)', 97, 0, 'monster_egg'
    MONSTER_EGG_COBBLESTONE = 'Monster egg (cobblestone)', 97, 1, 'monster_egg:1'
    MONSTER_EGG_STONE_BRICK = 'Monster egg (stone brick)', 97, 2, 'monster_egg:2'
    MONSTER_EGG_MOSSY_STONE_BRICK = 'Monster egg (mossy stone brick)', 97, 3, 'monster_egg:3'
    MONSTER_EGG_CRACKED_STONE = 'Monster egg (cracked stone)', 97, 4, 'monster_egg:4'
    MONSTER_EGG_CHISELED_STONE = 'Monster egg (chiseled stone)', 97, 5, 'monster_egg:5'
    STONE_BRICKS = 'Stone bricks', 98, 0, 'stonebrick'
    MOSSY_STONE_BRICKS = 'Mossy stone bricks', 98, 1, 'stonebrick:1'
    CRACKED_STONE_BRICKS = 'Cracked stone bricks', 98, 2, 'stonebrick:2'
    CHISELED_STONE_BRICK = 'Chiseled stone brick', 98, 3, 'stonebrick:3'
    BROWN_MUSHROOM_BLOCK = 'Brown mushroom (block)', 99, 0, 'brown_mushroom_block'
    RED_MUSHROOM_BLOCK = 'Red mushroom (block)', 100, 0, 'red_mushroom_block'
    IRON_BARS = 'Iron bars', 101, 0, 'iron_bars'
    GLASS_PANE = 'Glass pane', 102, 0, 'glass_pane'
    MELON_BLOCK = 'Melon (block)', 103, 0, 'melon_block'
    PUMPKIN_VINE = 'Pumpkin vine', 104, 0, 'pumpkin_stem'
    MELON_VINE = 'Melon vine', 105, 0, 'melon_stem'
    VINES = 'Vines', 106, 0, 'vine'
    FENCE_GATE_OAK = 'Fence gate (oak)', 107, 0, 'fence_gate'
    BRICK_STAIRS = 'Brick stairs', 108, 0, 'brick_stairs'
    STONE_BRICK_STAIRS = 'Stone brick stairs', 109, 0, 'stone_brick_stairs'
    MYCELIUM = 'Mycelium', 110, 0, 'mycelium'
    LILY_PAD = 'Lily pad', 111, 0, 'waterlily'
    NETHER_BRICK = 'Nether brick', 112, 0, 'nether_brick'
    NETHER_BRICK_FENCE = 'Nether brick fence', 113, 0, 'nether_brick_fence'
    NETHER_BRICK_STAIRS = 'Nether brick stairs', 114, 0, 'nether_brick_stairs'
    NETHER_WART = 'Nether wart', 115, 0, 'nether_wart'
    ENCHANTMENT_TABLE = 'Enchantment table', 116, 0, 'enchanting_table'
    BREWING_STAND_BLOCK = 'Brewing stand (block)', 117, 0, 'brewing_stand'
    CAULDRON_BLOCK = 'Cauldron (block)', 118, 0, 'cauldron'
    END_PORTAL = 'End portal', 119, 0, 'end_portal'
    END_PORTAL_FRAME = 'End portal frame', 120, 0, 'end_portal_frame'
    END_STONE = 'End stone', 121, 0, 'end_stone'
    DRAGON_EGG = 'Dragon egg', 122, 0, 'dragon_egg'
    REDSTONE_LAMP = 'Redstone lamp', 123, 0, 'redstone_lamp'
    REDSTONE_LAMP_ON = 'Redstone lamp (on)', 124, 0, 'lit_redstone_lamp'
    OAK_WOOD_SLAB_DOUBLE = 'Oak-wood slab (double)', 125, 0, 'double_wooden_slab'
    SPRUCE_WOOD_SLAB_DOUBLE = 'Spruce-wood slab (double)', 125, 1, 'double_wooden_slab:1'
    BIRCH_WOOD_SLAB_DOUBLE = 'Birch-wood slab (double)', 125, 2, 'double_wooden_slab:2'
    JUNGLE_WOOD_SLAB_DOUBLE = 'Jungle-wood slab (double)', 125, 3, 'double_wooden_slab:3'
    ACACIA_WOOD_SLAB_DOUBLE = 'Acacia wood slab (double)', 125, 4, 'double_wooden_slab:4'
    DARK_OAK_WOOD_SLAB_DOUBLE = 'Dark oak wood slab (double)', 125, 5, 'double_wooden_slab:5'
    OAK_WOOD_SLAB = 'Oak-wood slab', 126, 0, 'wooden_slab'
    SPRUCE_WOOD_SLAB = 'Spruce-wood slab', 126, 1, 'wooden_slab:1'
    BIRCH_WOOD_SLAB = 'Birch-wood slab', 126, 2, 'wooden_slab:2'
    JUNGLE_WOOD_SLAB = 'Jungle-wood slab', 126, 3, 'wooden_slab:3'
    ACACIA_WOOD_SLAB = 'Acacia wood slab', 126, 4, 'wooden_slab:4'
    DARK_OAK_WOOD_SLAB = 'Dark oak wood slab', 126, 5, 'wooden_slab:5'
    COCOA_PLANT = 'Cocoa plant', 127, 0, 'cocoa'
    SANDSTONE_STAIRS = 'Sandstone stairs', 128, 0, 'sandstone_stairs'
    EMERALD_ORE = 'Emerald ore', 129, 0, 'emerald_ore'
    ENDER_CHEST = 'Ender chest', 130, 0, 'ender_chest'
    TRIPWIRE_HOOK = 'Tripwire hook', 131, 0, 'tripwire_hook'
    TRIPWIRE = 'Tripwire', 132, 0, 'tripwire'
    BLOCK_OF_EMERALD = 'Block of emerald', 133, 0, 'emerald_block'
    WOODEN_STAIRS_SPRUCE = 'Wooden stairs (spruce)', 134, 0, 'spruce_stairs'
    WOODEN_STAIRS_BIRCH = 'Wooden stairs (birch)', 135, 0, 'birch_stairs'
    WOODEN_STAIRS_JUNGLE = 'Wooden stairs (jungle)', 136, 0, 'jungle_stairs'
    COMMAND_BLOCK = 'Command block', 137, 0, 'command_block'
    BEACON = 'Beacon', 138, 0, 'beacon'
    COBBLESTONE_WALL = 'Cobblestone wall', 139, 0, 'cobblestone_wall'
    MOSSY_COBBLESTONE_WALL = 'Mossy cobblestone wall', 139, 1, 'cobblestone_wall:1'
    FLOWER_POT_BLOCK = 'Flower pot (block)', 140, 0, 'flower_pot'
    CARROT_CROP = 'Carrot (crop)', 141, 0, 'carrots'
    POTATOES_CROP = 'Potatoes (crop)', 142, 0, 'potatoes'
    BUTTON_WOOD = 'Button (wood)', 143, 0, 'wooden_button'
    HEAD_BLOCK_SKELETON = 'Head block (skeleton)', 144, 0, 'skull'
    HEAD_BLOCK_WITHER = 'Head block (wither)', 144, 1, 'skull:1'
    HEAD_BLOCK_ZOMBIE = 'Head block (zombie)', 144, 2, 'skull:2'
    HEAD_BLOCK_STEVE = 'Head block (steve)', 144, 3, 'skull:3'
    HEAD_BLOCK_CREEPER = 'Head block (creeper)', 144, 4, 'skull:4'
    ANVIL = 'Anvil', 145, 0, 'anvil'
    ANVIL_SLIGHTLY_DAMAGED = 'Anvil (slightly damaged)', 145, 1, 'anvil:1'
    ANVIL_VERY_DAMAGED = 'Anvil (very damaged)', 145, 2, 'anvil:2'
    TRAPPED_CHEST = 'Trapped chest', 146, 0, 'trapped_chest'
    WEIGHTED_PRESSURE_PLATE_LIGHT = 'Weighted pressure plate (light)', 147, 0, 'light_weighted_pressure_plate'
    WEIGHTED_PRESSURE_PLATE_HEAVY = 'Weighted pressure plate (heavy)', 148, 0, 'heavy_weighted_pressure_plate'
    REDSTONE_COMPARATOR_OFF = 'Redstone comparator (off)', 149, 0, 'unpowered_comparator'
    REDSTONE_COMPARATOR_ON = 'Redstone comparator (on)', 150, 0, 'powered_comparator'
    DAYLIGHT_SENSOR = 'Daylight sensor', 151, 0, 'daylight_detector'
    BLOCK_OF_REDSTONE = 'Block of redstone', 152, 0, 'redstone_block'
    NETHER_QUARTZ_ORE = 'Nether quartz ore', 153, 0, 'quartz_ore'
    HOPPER = 'Hopper', 154, 0, 'hopper'
    QUARTZ_BLOCK = 'Quartz block', 155, 0, 'quartz_block'
    CHISELED_QUARTZ_BLOCK = 'Chiseled quartz block', 155, 1, 'quartz_block:1'
    PILLAR_QUARTZ_BLOCK = 'Pillar quartz block', 155, 2, 'quartz_block:2'
    QUARTZ_STAIRS = 'Quartz stairs', 156, 0, 'quartz_stairs'
    RAIL_ACTIVATOR = 'Rail (activator)', 157, 0, 'activator_rail'
    DROPPER = 'Dropper', 158, 0, 'dropper'
    STAINED_CLAY_WHITE = 'Stained clay (white)', 159, 0, 'stained_hardened_clay'
    STAINED_CLAY_ORANGE = 'Stained clay (orange)', 159, 1, 'stained_hardened_clay:1'
    STAINED_CLAY_MAGENTA = 'Stained clay (magenta)', 159, 2, 'stained_hardened_clay:2'
    STAINED_CLAY_LIGHT_BLUE = 'Stained clay (light blue)', 159, 3, 'stained_hardened_clay:3'
    STAINED_CLAY_YELLOW = 'Stained clay (yellow)', 159, 4, 'stained_hardened_clay:4'
    STAINED_CLAY_LIME = 'Stained clay (lime)', 159, 5, 'stained_hardened_clay:5'
    STAINED_CLAY_PINK = 'Stained clay (pink)', 159, 6, 'stained_hardened_clay:6'
    STAINED_CLAY_GRAY = 'Stained clay (gray)', 159, 7, 'stained_hardened_clay:7'
    STAINED_CLAY_LIGHT_GRAY = 'Stained clay (light gray)', 159, 8, 'stained_hardened_clay:8'
    STAINED_CLAY_CYAN = 'Stained clay (cyan)', 159, 9, 'stained_hardened_clay:9'
    STAINED_CLAY_PURPLE = 'Stained clay (purple)', 159, 10, 'stained_hardened_clay:10'
    STAINED_CLAY_BLUE = 'Stained clay (blue)', 159, 11, 'stained_hardened_clay:11'
    STAINED_CLAY_BROWN = 'Stained clay (brown)', 159, 12, 'stained_hardened_clay:12'
    STAINED_CLAY_GREEN = 'Stained clay (green)', 159, 13, 'stained_hardened_clay:13'
    STAINED_CLAY_RED = 'Stained clay (red)', 159, 14, 'stained_hardened_clay:14'
    STAINED_CLAY_BLACK = 'Stained clay (black)', 159, 15, 'stained_hardened_clay:15'
    STAINED_GLASS_PANE_WHITE = 'Stained glass pane (white)', 160, 0, 'stained_glass_pane'
    STAINED_GLASS_PANE_ORANGE = 'Stained glass pane (orange)', 160, 1, 'stained_glass_pane:1'
    STAINED_GLASS_PANE_MAGENTA = 'Stained glass pane (magenta)', 160, 2, 'stained_glass_pane:2'
    STAINED_GLASS_PANE_LIGHT_BLUE = 'Stained glass pane (light blue)', 160, 3, 'stained_glass_pane:3'
    STAINED_GLASS_PANE_YELLOW = 'Stained glass pane (yellow)', 160, 4, 'stained_glass_pane:4'
    STAINED_GLASS_PANE_LIME = 'Stained glass pane (lime)', 160, 5, 'stained_glass_pane:5'
    STAINED_GLASS_PANE_PINK = 'Stained glass pane (pink)', 160, 6, 'stained_glass_pane:6'
    STAINED_GLASS_PANE_GRAY = 'Stained glass pane (gray)', 160, 7, 'stained_glass_pane:7'
    STAINED_GLASS_PANE_LIGHT_GRAY = 'Stained glass pane (light gray)', 160, 8, 'stained_glass_pane:8'
    STAINED_GLASS_PANE_CYAN = 'Stained glass pane (cyan)', 160, 9, 'stained_glass_pane:9'
    STAINED_GLASS_PANE_PURPLE = 'Stained glass pane (purple)', 160, 10, 'stained_glass_pane:10'
    STAINED_GLASS_PANE_BLUE = 'Stained glass pane (blue)', 160, 11, 'stained_glass_pane:11'
    STAINED_GLASS_PANE_BROWN = 'Stained glass pane (brown)', 160, 12, 'stained_glass_pane:12'
    STAINED_GLASS_PANE_GREEN = 'Stained glass pane (green)', 160, 13, 'stained_glass_pane:13'
    STAINED_GLASS_PANE_RED = 'Stained glass pane (red)', 160, 14, 'stained_glass_pane:14'
    STAINED_GLASS_PANE_BLACK = 'Stained glass pane (black)', 160, 15, 'stained_glass_pane:15'
    LEAVES_ACACIA = 'Leaves (acacia)', 161, 0, 'leaves2'
    LEAVES_DARK_OAK = 'Leaves (dark oak)', 161, 1, 'leaves2:1'
    WOOD_ACACIA_OAK = 'Wood (acacia oak)', 162, 0, 'log2'
    WOOD_DARK_OAK = 'Wood (dark oak)', 162, 1, 'log2:1'
    WOODEN_STAIRS_ACACIA = 'Wooden stairs (acacia)', 163, 0, 'acacia_stairs'
    WOODEN_STAIRS_DARK_OAK = 'Wooden stairs (dark oak)', 164, 0, 'dark_oak_stairs'
    SLIME_BLOCK = 'Slime block', 165, 0, 'slime'
    BARRIER = 'Barrier', 166, 0, 'barrier'
    IRON_TRAPDOOR = 'Iron trapdoor', 167, 0, 'iron_trapdoor'
    PRISMARINE = 'Prismarine', 168, 0, 'prismarine'
    PRISMARINE_BRICKS = 'Prismarine bricks', 168, 1, 'prismarine:1'
    DARK_PRISMARINE = 'Dark prismarine', 168, 2, 'prismarine:2'
    SEA_LANTERN = 'Sea lantern', 169, 0, 'sea_lantern'
    HAY_BALE = 'Hay bale', 170, 0, 'hay_block'
    CARPET_WHITE = 'Carpet (white)', 171, 0, 'carpet'
    CARPET_ORANGE = 'Carpet (orange)', 171, 1, 'carpet:1'
    CARPET_MAGENTA = 'Carpet (magenta)', 171, 2, 'carpet:2'
    CARPET_LIGHT_BLUE = 'Carpet (light blue)', 171, 3, 'carpet:3'
    CARPET_YELLOW = 'Carpet (yellow)', 171, 4, 'carpet:4'
    CARPET_LIME = 'Carpet (lime)', 171, 5, 'carpet:5'
    CARPET_PINK = 'Carpet (pink)', 171, 6, 'carpet:6'
    CARPET_GREY = 'Carpet (grey)', 171, 7, 'carpet:7'
    CARPET_LIGHT_GRAY = 'Carpet (light gray)', 171, 8, 'carpet:8'
    CARPET_CYAN = 'Carpet (cyan)', 171, 9, 'carpet:9'
    CARPET_PURPLE = 'Carpet (purple)', 171, 10, 'carpet:10'
    CARPET_BLUE = 'Carpet (blue)', 171, 11, 'carpet:11'
    CARPET_BROWN = 'Carpet (brown)', 171, 12, 'carpet:12'
    CARPET_GREEN = 'Carpet (green)', 171, 13, 'carpet:13'
    CARPET_RED = 'Carpet (red)', 171, 14, 'carpet:14'
    CARPET_BLACK = 'Carpet (black)', 171, 15, 'carpet:15'
    HARDENED_CLAY = 'Hardened clay', 172, 0, 'hardened_clay'
    BLOCK_OF_COAL = 'Block of coal', 173, 0, 'coal_block'
    PACKED_ICE = 'Packed ice', 174, 0, 'packed_ice'
    SUNFLOWER = 'Sunflower', 175, 0, 'double_plant'
    LILAC = 'Lilac', 175, 1, 'double_plant:1'
    DOUBLE_TALLGRASS = 'Double tallgrass', 175, 2, 'double_plant:2'
    LARGE_FERN = 'Large fern', 175, 3, 'double_plant:3'
    ROSE_BUSH = 'Rose bush', 175, 4, 'double_plant:4'
    PEONY = 'Peony', 175, 5, 'double_plant:5'
    STANDING_BANNER_BLOCK = 'Standing banner (block)', 176, 0, 'standing_banner'
    WALL_BANNER_BLOCK = 'Wall banner (block)', 177, 0, 'wall_banner'
    INVERTED_DAYLIGHT_SENSOR = 'Inverted daylight sensor', 178, 0, 'daylight_detector_inverted'
    RED_SANDSTONE = 'Red sandstone', 179, 0, 'red_sandstone'
    RED_SANDSTONE_CHISELED = 'Red sandstone (chiseled)', 179, 1, 'red_sandstone:1'
    RED_SANDSTONE_SMOOTH = 'Red sandstone (smooth)', 179, 2, 'red_sandstone:2'
    RED_SANDSTONE_STAIRS = 'Red sandstone stairs', 180, 0, 'red_sandstone_stairs'
    RED_SANDSTONE_SLAB_DOUBLE = 'Red sandstone slab (double)', 181, 0, 'double_stone_slab2'
    RED_SANDSTONE_SLAB = 'Red sandstone slab', 182, 0, 'stone_slab2'
    FENCE_GATE_SPRUCE = 'Fence gate (spruce)', 183, 0, 'spruce_fence_gate'
    FENCE_GATE_BIRCH = 'Fence gate (birch)', 184, 0, 'birch_fence_gate'
    FENCE_GATE_JUNGLE = 'Fence gate (jungle)', 185, 0, 'jungle_fence_gate'
    FENCE_GATE_DARK_OAK = 'Fence gate (dark oak)', 186, 0, 'dark_oak_fence_gate'
    FENCE_GATE_ACACIA = 'Fence gate (acacia)', 187, 0, 'acacia_fence_gate'
    FENCE_SPRUCE = 'Fence (spruce)', 188, 0, 'spruce_fence'
    FENCE_BIRCH = 'Fence (birch)', 189, 0, 'birch_fence'
    FENCE_JUNGLE = 'Fence (jungle)', 190, 0, 'jungle_fence'
    FENCE_DARK_OAK = 'Fence (dark oak)', 191, 0, 'dark_oak_fence'
    FENCE_ACACIA = 'Fence (acacia)', 192, 0, 'acacia_fence'
    WOODEN_DOOR_BLOCK_SPRUCE = 'Wooden door block (spruce)', 193, 0, 'spruce_door'
    WOODEN_DOOR_BLOCK_BIRCH = 'Wooden door block (birch)', 194, 0, 'birch_door'
    WOODEN_DOOR_BLOCK_JUNGLE = 'Wooden door block (jungle)', 195, 0, 'jungle_door'
    WOODEN_DOOR_BLOCK_ACACIA = 'Wooden door block (acacia)', 196, 0, 'acacia_door'
    WOODEN_DOOR_BLOCK_DARK_OAK = 'Wooden door block (dark oak)', 197, 0, 'dark_oak_door'
    # non-placeable
    __phase__ = 198
    END_ROD = 'End rod', 198, 0, 'end_rod'
    CHORUS_PLANT = 'Chorus plant', 199, 0, 'chorus_plant'
    CHORUS_FLOWER = 'Chorus flower', 200, 0, 'chorus_flower'
    PURPUR_BLOCK = 'Purpur block', 201, 0, 'purpur_block'
    PURPUR_PILLAR = 'Purpur pillar', 202, 0, 'purpur_pillar'
    PURPUR_STAIRS = 'Purpur stairs', 203, 0, 'purpur_stairs'
    PURPUR_SLAB_DOUBLE = 'Purpur slab (double)', 204, 0, 'purpur_double_slab'
    PURPUR_SLAB = 'Purpur slab', 205, 0, 'purpur_slab'
    END_STONE_BRICKS = 'End stone bricks', 206, 0, 'end_bricks'
    GRASS_PATH = 'Grass path', 208, 0, 'grass_path'
    END_GATEWAY = 'End gateway', 209, 0, 'end_gateway'
    FROSTED_ICE = 'Frosted ice', 212, 0, 'frosted_ice'
    MAGMA_BLOCK = 'Magma block', 213, 0, 'magma'
    NETHER_WART_BLOCK = 'Nether wart (block)', 214, 0, 'nether_wart_block'
    NETHER_BRICK_RED = 'Nether brick (red)', 215, 0, 'red_nether_brick'
    BONE_BLOCK = 'Bone block', 216, 0, 'bone_block'
    OBSERVER = 'Observer', 218, 0, 'observer'
    SHULKER_BOX_PURPLE = 'Shulker box (purple)', 229, 0, 'purple_shulker_box'
    STRUCTURE_BLOCK = 'Structure block', 255, 0, 'structure_block'
    IRON_SHOVEL = 'Iron shovel', 256, 0, 'iron_shovel'
    IRON_PICKAXE = 'Iron pickaxe', 257, 0, 'iron_pickaxe'
    IRON_AXE = 'Iron axe', 258, 0, 'iron_axe'
    FLINT_AND_STEEL = 'Flint and steel', 259, 0, 'flint_and_steel'
    APPLE = 'Apple', 260, 0, 'apple'
    BOW = 'Bow', 261, 0, 'bow'
    ARROW = 'Arrow', 262, 0, 'arrow'
    COAL = 'Coal', 263, 0, 'coal'
    CHARCOAL = 'Charcoal', 263, 1, 'coal:1'
    DIAMOND_GEM = 'Diamond gem', 264, 0, 'diamond'
    IRON_INGOT = 'Iron ingot', 265, 0, 'iron_ingot'
    GOLD_INGOT = 'Gold ingot', 266, 0, 'gold_ingot'
    IRON_SWORD = 'Iron sword', 267, 0, 'iron_sword'
    WOODEN_SWORD = 'Wooden sword', 268, 0, 'wooden_sword'
    WOODEN_SHOVEL = 'Wooden shovel', 269, 0, 'wooden_shovel'
    WOODEN_PICKAXE = 'Wooden pickaxe', 270, 0, 'wooden_pickaxe'
    WOODEN_AXE = 'Wooden axe', 271, 0, 'wooden_axe'
    STONE_SWORD = 'Stone sword', 272, 0, 'stone_sword'
    STONE_SHOVEL = 'Stone shovel', 273, 0, 'stone_shovel'
    STONE_PICKAXE = 'Stone pickaxe', 274, 0, 'stone_pickaxe'
    STONE_AXE = 'Stone axe', 275, 0, 'stone_axe'
    DIAMOND_SWORD = 'Diamond sword', 276, 0, 'diamond_sword'
    DIAMOND_SHOVEL = 'Diamond shovel', 277, 0, 'diamond_shovel'
    DIAMOND_PICKAXE = 'Diamond pickaxe', 278, 0, 'diamond_pickaxe'
    DIAMOND_AXE = 'Diamond axe', 279, 0, 'diamond_axe'
    STICK = 'Stick', 280, 0, 'stick'
    BOWL = 'Bowl', 281, 0, 'bowl'
    MUSHROOM_STEW = 'Mushroom stew', 282, 0, 'mushroom_stew'
    GOLD_SWORD = 'Gold sword', 283, 0, 'golden_sword'
    GOLD_SHOVEL = 'Gold shovel', 284, 0, 'golden_shovel'
    GOLD_PICKAXE = 'Gold pickaxe', 285, 0, 'golden_pickaxe'
    GOLD_AXE = 'Gold axe', 286, 0, 'golden_axe'
    STRING = 'String', 287, 0, 'string'
    FEATHER = 'Feather', 288, 0, 'feather'
    GUNPOWDER = 'Gunpowder', 289, 0, 'gunpowder'
    WOODEN_HOE = 'Wooden hoe', 290, 0, 'wooden_hoe'
    STONE_HOE = 'Stone hoe', 291, 0, 'stone_hoe'
    IRON_HOE = 'Iron hoe', 292, 0, 'iron_hoe'
    DIAMOND_HOE = 'Diamond hoe', 293, 0, 'diamond_hoe'
    GOLD_HOE = 'Gold hoe', 294, 0, 'golden_hoe'
    WHEAT_SEEDS = 'Wheat seeds', 295, 0, 'wheat_seeds'
    WHEAT = 'Wheat', 296, 0, 'wheat'
    BREAD = 'Bread', 297, 0, 'bread'
    LEATHER_HELMET = 'Leather helmet', 298, 0, 'leather_helmet'
    LEATHER_CHESTPLATE = 'Leather chestplate', 299, 0, 'leather_chestplate'
    LEATHER_LEGGINGS = 'Leather leggings', 300, 0, 'leather_leggings'
    LEATHER_BOOTS = 'Leather boots', 301, 0, 'leather_boots'
    CHAINMAIL_HELMET = 'Chainmail helmet', 302, 0, 'chainmail_helmet'
    CHAINMAIL_CHESTPLATE = 'Chainmail chestplate', 303, 0, 'chainmail_chestplate'
    CHAINMAIL_LEGGINGS = 'Chainmail leggings', 304, 0, 'chainmail_leggings'
    CHAINMAIL_BOOTS = 'Chainmail boots', 305, 0, 'chainmail_boots'
    IRON_HELMET = 'Iron helmet', 306, 0, 'iron_helmet'
    IRON_CHESTPLATE = 'Iron chestplate', 307, 0, 'iron_chestplate'
    IRON_LEGGINGS = 'Iron leggings', 308, 0, 'iron_leggings'
    IRON_BOOTS = 'Iron boots', 309, 0, 'iron_boots'
    DIAMOND_HELMET = 'Diamond helmet', 310, 0, 'diamond_helmet'
    DIAMOND_CHESTPLATE = 'Diamond chestplate', 311, 0, 'diamond_chestplate'
    DIAMOND_LEGGINGS = 'Diamond leggings', 312, 0, 'diamond_leggings'
    DIAMOND_BOOTS = 'Diamond boots', 313, 0, 'diamond_boots'
    GOLD_HELMET = 'Gold helmet', 314, 0, 'golden_helmet'
    GOLD_CHESTPLATE = 'Gold chestplate', 315, 0, 'golden_chestplate'
    GOLD_LEGGINGS = 'Gold leggings', 316, 0, 'golden_leggings'
    GOLD_BOOTS = 'Gold boots', 317, 0, 'golden_boots'
    FLINT = 'Flint', 318, 0, 'flint'
    RAW_PORKCHOP = 'Raw porkchop', 319, 0, 'porkchop'
    COOKED_PORKCHOP = 'Cooked porkchop', 320, 0, 'cooked_porkchop'
    PAINTING = 'Painting', 321, 0, 'painting'
    GOLDEN_APPLE = 'Golden apple', 322, 0, 'golden_apple'
    ENCHANTED_GOLDEN_APPLE = 'Enchanted golden apple', 322, 1, 'golden_apple:1'
    SIGN = 'Sign', 323, 0, 'sign'
    WOODEN_DOOR = 'Wooden door', 324, 0, 'wooden_door'
    BUCKET = 'Bucket', 325, 0, 'bucket'
    BUCKET_WATER = 'Bucket (water)', 326, 0, 'water_bucket'
    BUCKET_LAVA = 'Bucket (lava)', 327, 0, 'lava_bucket'
    MINECART = 'Minecart', 328, 0, 'minecart'
    SADDLE = 'Saddle', 329, 0, 'saddle'
    IRON_DOOR = 'Iron door', 330, 0, 'iron_door'
    REDSTONE_DUST = 'Redstone dust', 331, 0, 'redstone'
    SNOWBALL = 'Snowball', 332, 0, 'snowball'
    BOAT = 'Boat', 333, 0, 'boat'
    LEATHER = 'Leather', 334, 0, 'leather'
    BUCKET_MILK = 'Bucket (milk)', 335, 0, 'milk_bucket'
    CLAY_BRICK = 'Clay brick', 336, 0, 'brick'
    CLAY = 'Clay', 337, 0, 'clay_ball'
    SUGAR_CANE = 'Sugar cane', 338, 0, 'reeds'
    PAPER = 'Paper', 339, 0, 'paper'
    BOOK = 'Book', 340, 0, 'book'
    SLIME_BALL = 'Slime ball', 341, 0, 'slimeball'
    MINECART_STORAGE = 'Minecart (storage)', 342, 0, 'chest_minecart'
    MINECART_POWERED = 'Minecart (powered)', 343, 0, 'furnace_minecart'
    EGG = 'Egg', 344, 0, 'egg'
    COMPASS = 'Compass', 345, 0, 'compass'
    FISHING_ROD = 'Fishing rod', 346, 0, 'fishing_rod'
    WATCH = 'Watch', 347, 0, 'clock'
    GLOWSTONE_DUST = 'Glowstone dust', 348, 0, 'glowstone_dust'
    RAW_FISH = 'Raw fish', 349, 0, 'fish'
    RAW_SALMON = 'Raw salmon', 349, 1, 'fish:1'
    CLOWNFISH = 'Clownfish', 349, 2, 'fish:2'
    PUFFERFISH = 'Pufferfish', 349, 3, 'fish:3'
    COOKED_FISH = 'Cooked fish', 350, 0, 'cooked_fished'
    COOKED_SALMON = 'Cooked salmon', 350, 1, 'cooked_fished:1'
    COOKED_CLOWNFISH = 'Clownfish', 350, 2, 'cooked_fished:2'
    COOKED_PUFFERFISH = 'Pufferfish', 350, 3, 'cooked_fished:3'
    BONE_MEAL = 'Bone meal', 351, 0, 'dye'
    ROSE_RED_DYE = 'Rose red dye', 351, 1, 'dye:1'
    CACTUS_GREEN_DYE = 'Cactus green dye', 351, 2, 'dye:2'
    COCOA_BEAN = 'Cocoa bean', 351, 3, 'dye:3'
    LAPIS_LAZULI = 'Lapis lazuli', 351, 4, 'dye:4'
    PURPLE_DYE = 'Purple dye', 351, 5, 'dye:5'
    CYAN_DYE = 'Cyan dye', 351, 6, 'dye:6'
    LIGHT_GRAY_DYE = 'Light gray dye', 351, 7, 'dye:7'
    GRAY_DYE = 'Gray dye', 351, 8, 'dye:8'
    PINK_DYE = 'Pink dye', 351, 9, 'dye:9'
    LIME_DYE = 'Lime dye', 351, 10, 'dye:10'
    DANDELION_YELLOW_DYE = 'Dandelion yellow dye', 351, 11, 'dye:11'
    LIGHT_BLUE_DYE = 'Light blue dye', 351, 12, 'dye:12'
    MAGENTA_DYE = 'Magenta dye', 351, 13, 'dye:13'
    ORANGE_DYE = 'Orange dye', 351, 14, 'dye:14'
    INK_SACK = 'Ink sack', 351, 15, 'dye:15'
    BONE = 'Bone', 352, 0, 'bone'
    SUGAR = 'Sugar', 353, 0, 'sugar'
    CAKE = 'Cake', 354, 0, 'cake'
    BED = 'Bed', 355, 0, 'bed'
    REDSTONE_REPEATER = 'Redstone repeater', 356, 0, 'repeater'
    COOKIE = 'Cookie', 357, 0, 'cookie'
    MAP = 'Map', 358, 0, 'filled_map'
    SHEARS = 'Shears', 359, 0, 'shears'
    MELON_SLICE = 'Melon (slice)', 360, 0, 'melon'
    PUMPKIN_SEEDS = 'Pumpkin seeds', 361, 0, 'pumpkin_seeds'
    MELON_SEEDS = 'Melon seeds', 362, 0, 'melon_seeds'
    RAW_BEEF = 'Raw beef', 363, 0, 'beef'
    STEAK = 'Steak', 364, 0, 'cooked_beef'
    RAW_CHICKEN = 'Raw chicken', 365, 0, 'chicken'
    COOKED_CHICKEN = 'Cooked chicken', 366, 0, 'cooked_chicken'
    ROTTEN_FLESH = 'Rotten flesh', 367, 0, 'rotten_flesh'
    ENDER_PEARL = 'Ender pearl', 368, 0, 'ender_pearl'
    BLAZE_ROD = 'Blaze rod', 369, 0, 'blaze_rod'
    GHAST_TEAR = 'Ghast tear', 370, 0, 'ghast_tear'
    GOLD_NUGGET = 'Gold nugget', 371, 0, 'gold_nugget'
    NETHER_WART_SEEDS = 'Nether wart seeds', 372, 0, 'nether_wart'
    WATER_BOTTLE = 'Water bottle', 373, 0, 'potion'
    AWKWARD_POTION = 'Awkward potion', 373, 16, 'potion:16'
    THICK_POTION = 'Thick potion', 373, 32, 'potion:32'
    MUNDANE_POTION = 'Mundane potion', 373, 64, 'potion:64'
    REGENERATION_POTION_0_45 = 'Regeneration potion (0:45)', 373, 8193, 'potion:8193'
    SWIFTNESS_POTION_3_00 = 'Swiftness potion (3:00)', 373, 8194, 'potion:8194'
    FIRE_RESISTANCE_POTION_3_00 = 'Fire resistance potion (3:00)', 373, 8195, 'potion:8195'
    POISON_POTION_0_45 = 'Poison potion (0:45)', 373, 8196, 'potion:8196'
    HEALING_POTION = 'Healing potion', 373, 8197, 'potion:8197'
    NIGHT_VISION_POTION_3_00 = 'Night vision potion (3:00)', 373, 8198, 'potion:8198'
    WEAKNESS_POTION_1_30 = 'Weakness potion (1:30)', 373, 8200, 'potion:8200'
    STRENGTH_POTION_3_00 = 'Strength potion (3:00)', 373, 8201, 'potion:8201'
    SLOWNESS_POTION_1_30 = 'Slowness potion (1:30)', 373, 8202, 'potion:8202'
    HARMING_POTION = 'Harming potion', 373, 8204, 'potion:8204'
    WATER_BREATHING_POTION_3_00 = 'Water breathing potion (3:00)', 373, 8205, 'potion:8205'
    INVISIBILITY_POTION_3_00 = 'Invisibility potion (3:00)', 373, 8206, 'potion:8206'
    REGENERATION_POTION_II_0_22 = 'Regeneration potion ii (0:22)', 373, 8225, 'potion:8225'
    SWIFTNESS_POTION_II_1_30 = 'Swiftness potion ii (1:30)', 373, 8226, 'potion:8226'
    POISON_POTION_II_0_22 = 'Poison potion ii (0:22)', 373, 8228, 'potion:8228'
    HEALING_POTION_II = 'Healing potion ii', 373, 8229, 'potion:8229'
    STRENGTH_POTION_II_1_30 = 'Strength potion ii (1:30)', 373, 8233, 'potion:8233'
    LEAPING_POTION_II_1_30 = 'Leaping potion ii (1:30)', 373, 8235, 'potion:8235'
    HARMING_POTION_II = 'Harming potion ii', 373, 8236, 'potion:8236'
    REGENERATION_POTION_2_00 = 'Regeneration potion (2:00)', 373, 8257, 'potion:8257'
    SWIFTNESS_POTION_8_00 = 'Swiftness potion (8:00)', 373, 8258, 'potion:8258'
    FIRE_RESISTANCE_POTION_8_00 = 'Fire resistance potion (8:00)', 373, 8259, 'potion:8259'
    POISON_POTION_2_00 = 'Poison potion (2:00)', 373, 8260, 'potion:8260'
    NIGHT_VISION_POTION_8_00 = 'Night vision potion (8:00)', 373, 8262, 'potion:8262'
    WEAKNESS_POTION_4_00 = 'Weakness potion (4:00)', 373, 8264, 'potion:8264'
    STRENGTH_POTION_8_00 = 'Strength potion (8:00)', 373, 8265, 'potion:8265'
    SLOWNESS_POTION_4_00 = 'Slowness potion (4:00)', 373, 8266, 'potion:8266'
    LEAPING_POTION_3_00 = 'Leaping potion (3:00)', 373, 8267, 'potion:8267'
    WATER_BREATHING_POTION_8_00 = 'Water breathing potion (8:00)', 373, 8269, 'potion:8269'
    INVISIBILITY_POTION_8_00 = 'Invisibility potion (8:00)', 373, 8270, 'potion:8270'
    REGENERATION_POTION_II_1_00 = 'Regeneration potion ii (1:00)', 373, 8289, 'potion:8289'
    SWIFTNESS_POTION_II_4_00 = 'Swiftness potion ii (4:00)', 373, 8290, 'potion:8290'
    POISON_POTION_II_1_00 = 'Poison potion ii (1:00)', 373, 8292, 'potion:8292'
    STRENGTH_POTION_II_4_00 = 'Strength potion ii (4:00)', 373, 8297, 'potion:8297'
    REGENERATION_SPLASH_0_33 = 'Regeneration splash (0:33)', 373, 16385, 'potion:16385'
    SWIFTNESS_SPLASH_2_15 = 'Swiftness splash (2:15)', 373, 16386, 'potion:16386'
    FIRE_RESISTANCE_SPLASH_2_15 = 'Fire resistance splash (2:15)', 373, 16387, 'potion:16387'
    POISON_SPLASH_0_33 = 'Poison splash (0:33)', 373, 16388, 'potion:16388'
    HEALING_SPLASH = 'Healing splash', 373, 16389, 'potion:16389'
    NIGHT_VISION_SPLASH_2_15 = 'Night vision splash (2:15)', 373, 16390, 'potion:16390'
    WEAKNESS_SPLASH_1_07 = 'Weakness splash (1:07)', 373, 16392, 'potion:16392'
    STRENGTH_SPLASH_2_15 = 'Strength splash (2:15)', 373, 16393, 'potion:16393'
    SLOWNESS_SPLASH_1_07 = 'Slowness splash (1:07)', 373, 16394, 'potion:16394'
    HARMING_SPLASH = 'Harming splash', 373, 16396, 'potion:16396'
    BREATHING_SPLASH_2_15 = 'Breathing splash (2:15)', 373, 16397, 'potion:16397'
    INVISIBILITY_SPLASH_2_15 = 'Invisibility splash (2:15)', 373, 16398, 'potion:16398'
    REGENERATION_SPLASH_II_0_16 = 'Regeneration splash ii (0:16)', 373, 16417, 'potion:16417'
    SWIFTNESS_SPLASH_II_1_07 = 'Swiftness splash ii (1:07)', 373, 16418, 'potion:16418'
    POISON_SPLASH_II_0_16 = 'Poison splash ii (0:16)', 373, 16420, 'potion:16420'
    HEALING_SPLASH_II = 'Healing splash ii', 373, 16421, 'potion:16421'
    STRENGTH_SPLASH_II_1_07 = 'Strength splash ii (1:07)', 373, 16425, 'potion:16425'
    LEAPING_SPLASH_II_1_07 = 'Leaping splash ii (1:07)', 373, 16427, 'potion:16427'
    HARMING_SPLASH_II = 'Harming splash ii', 373, 16428, 'potion:16428'
    REGENERATION_SPLASH_1_30 = 'Regeneration splash (1:30)', 373, 16449, 'potion:16449'
    SWIFTNESS_SPLASH_6_00 = 'Swiftness splash (6:00)', 373, 16450, 'potion:16450'
    FIRE_RESISTANCE_SPLASH_6_00 = 'Fire resistance splash (6:00)', 373, 16451, 'potion:16451'
    POISON_SPLASH_1_30 = 'Poison splash (1:30)', 373, 16452, 'potion:16452'
    NIGHT_VISION_SPLASH_6_00 = 'Night vision splash (6:00)', 373, 16454, 'potion:16454'
    WEAKNESS_SPLASH_3_00 = 'Weakness splash (3:00)', 373, 16456, 'potion:16456'
    STRENGTH_SPLASH_6_00 = 'Strength splash (6:00)', 373, 16457, 'potion:16457'
    SLOWNESS_SPLASH_3_00 = 'Slowness splash (3:00)', 373, 16458, 'potion:16458'
    LEAPING_SPLASH_2_15 = 'Leaping splash (2:15)', 373, 16459, 'potion:16459'
    BREATHING_SPLASH_6_00 = 'Breathing splash (6:00)', 373, 16461, 'potion:16461'
    INVISIBILITY_SPLASH_6_00 = 'Invisibility splash (6:00)', 373, 16462, 'potion:16462'
    REGENERATION_SPLASH_II_0_45 = 'Regeneration splash ii (0:45)', 373, 16481, 'potion:16481'
    SWIFTNESS_SPLASH_II_3_00 = 'Swiftness splash ii (3:00)', 373, 16482, 'potion:16482'
    POISON_SPLASH_II_0_45 = 'Poison splash ii (0:45)', 373, 16484, 'potion:16484'
    STRENGTH_SPLASH_II_3_00 = 'Strength splash ii (3:00)', 373, 16489, 'potion:16489'
    GLASS_BOTTLE = 'Glass bottle', 374, 0, 'glass_bottle'
    SPIDER_EYE = 'Spider eye', 375, 0, 'spider_eye'
    FERMENTED_SPIDER_EYE = 'Fermented spider eye', 376, 0, 'fermented_spider_eye'
    BLAZE_POWDER = 'Blaze powder', 377, 0, 'blaze_powder'
    MAGMA_CREAM = 'Magma cream', 378, 0, 'magma_cream'
    BREWING_STAND = 'Brewing stand', 379, 0, 'brewing_stand'
    CAULDRON = 'Cauldron', 380, 0, 'cauldron'
    EYE_OF_ENDER = 'Eye of ender', 381, 0, 'ender_eye'
    GLISTERING_MELON_SLICE = 'Glistering melon (slice)', 382, 0, 'speckled_melon'
    SPAWN_EGG_CREEPER = 'Spawn egg (creeper)', 383, 50, 'spawn_egg:50'
    SPAWN_EGG_SKELETON = 'Spawn egg (skeleton)', 383, 51, 'spawn_egg:51'
    SPAWN_EGG_SPIDER = 'Spawn egg (spider)', 383, 52, 'spawn_egg:52'
    SPAWN_EGG_ZOMBIE = 'Spawn egg (zombie)', 383, 54, 'spawn_egg:54'
    SPAWN_EGG_SLIME = 'Spawn egg (slime)', 383, 55, 'spawn_egg:55'
    SPAWN_EGG_GHAST = 'Spawn egg (ghast)', 383, 56, 'spawn_egg:56'
    SPAWN_EGG_ZOMBIE_PIGMEN = 'Spawn egg (zombie pigmen)', 383, 57, 'spawn_egg:57'
    SPAWN_EGG_ENDERMEN = 'Spawn egg (endermen)', 383, 58, 'spawn_egg:58'
    SPAWN_EGG_CAVE_SPIDER = 'Spawn egg (cave spider)', 383, 59, 'spawn_egg:59'
    SPAWN_EGG_SILVERFISH = 'Spawn egg (silverfish)', 383, 60, 'spawn_egg:60'
    SPAWN_EGG_BLAZE = 'Spawn egg (blaze)', 383, 61, 'spawn_egg:61'
    SPAWN_EGG_MAGMA_CUBE = 'Spawn egg (magma cube)', 383, 62, 'spawn_egg:62'
    SPAWN_EGG_BAT = 'Spawn egg (bat)', 383, 65, 'spawn_egg:65'
    SPAWN_EGG_WITCH = 'Spawn egg (witch)', 383, 66, 'spawn_egg:66'
    SPAWN_EGG_ENDERMITE = 'Spawn egg (endermite)', 383, 67, 'spawn_egg:67'
    SPAWN_EGG_GUARDIAN = 'Spawn egg (guardian)', 383, 68, 'spawn_egg:68'
    SPAWN_EGG_SHULKER = 'Spawn egg (shulker)', 383, 69, 'spawn_egg:69'
    SPAWN_EGG_PIG = 'Spawn egg (pig)', 383, 90, 'spawn_egg:90'
    SPAWN_EGG_SHEEP = 'Spawn egg (sheep)', 383, 91, 'spawn_egg:91'
    SPAWN_EGG_COW = 'Spawn egg (cow)', 383, 92, 'spawn_egg:92'
    SPAWN_EGG_CHICKEN = 'Spawn egg (chicken)', 383, 93, 'spawn_egg:93'
    SPAWN_EGG_SQUID = 'Spawn egg (squid)', 383, 94, 'spawn_egg:94'
    SPAWN_EGG_WOLF = 'Spawn egg (wolf)', 383, 95, 'spawn_egg:95'
    SPAWN_EGG_MOOSHROOM = 'Spawn egg (mooshroom)', 383, 96, 'spawn_egg:96'
    SPAWN_EGG_OCELOT = 'Spawn egg (ocelot)', 383, 98, 'spawn_egg:98'
    SPAWN_EGG_HORSE = 'Spawn egg (horse)', 383, 100, 'spawn_egg:100'
    SPAWN_EGG_RABBIT = 'Spawn egg (rabbit)', 383, 101, 'spawn_egg:101'
    SPAWN_EGG_POLAR_BEAR = 'Spawn egg (polar bear)', 383, 102, 'spawn_egg:102'
    SPAWN_EGG_VILLAGER = 'Spawn egg (villager)', 383, 120, 'spawn_egg:120'
    BOTTLE_OF_ENCHANTING = 'Bottle of enchanting', 384, 0, 'experience_bottle'
    FIRE_CHARGE = 'Fire charge', 385, 0, 'fire_charge'
    BOOK_AND_QUILL = 'Book and quill', 386, 0, 'writable_book'
    WRITTEN_BOOK = 'Written book', 387, 0, 'written_book'
    EMERALD = 'Emerald', 388, 0, 'emerald'
    ITEM_FRAME = 'Item frame', 389, 0, 'item_frame'
    FLOWER_POT = 'Flower pot', 390, 0, 'flower_pot'
    CARROT = 'Carrot', 391, 0, 'carrot'
    POTATO = 'Potato', 392, 0, 'potato'
    BAKED_POTATO = 'Baked potato', 393, 0, 'baked_potato'
    POISONOUS_POTATO = 'Poisonous potato', 394, 0, 'poisonous_potato'
    EMPTY_MAP = 'Empty map', 395, 0, 'map'
    GOLDEN_CARROT = 'Golden carrot', 396, 0, 'golden_carrot'
    HEAD_SKELETON = 'Head (skeleton)', 397, 0, 'skull'
    HEAD_WITHER = 'Head (wither)', 397, 1, 'skull:1'
    HEAD_ZOMBIE = 'Head (zombie)', 397, 2, 'skull:2'
    HEAD_STEVE = 'Head (steve)', 397, 3, 'skull:3'
    HEAD_CREEPER = 'Head (creeper)', 397, 4, 'skull:4'
    CARROT_ON_A_STICK = 'Carrot on a stick', 398, 0, 'carrot_on_a_stick'
    NETHER_STAR = 'Nether star', 399, 0, 'nether_star'
    PUMPKIN_PIE = 'Pumpkin pie', 400, 0, 'pumpkin_pie'
    FIREWORK_ROCKET = 'Firework rocket', 401, 0, 'fireworks'
    FIREWORK_STAR = 'Firework star', 402, 0, 'firework_charge'
    ENCHANTED_BOOK = 'Enchanted book', 403, 0, 'enchanted_book'
    REDSTONE_COMPARATOR = 'Redstone comparator', 404, 0, 'comparator'
    NETHER_BRICK_ITEM = 'Nether brick (item)', 405, 0, 'netherbrick'
    NETHER_QUARTZ = 'Nether quartz', 406, 0, 'quartz'
    MINECART_TNT = 'Minecart (tnt)', 407, 0, 'tnt_minecart'
    MINECART_HOPPER = 'Minecart (hopper)', 408, 0, 'hopper_minecart'
    PRISMARINE_SHARD = 'Prismarine shard', 409, 0, 'prismarine_shard'
    PRISMARINE_CRYSTALS = 'Prismarine crystals', 410, 0, 'prismarine_crystals'
    RAW_RABBIT = 'Raw rabbit', 411, 0, 'rabbit'
    COOKED_RABBIT = 'Cooked rabbit', 412, 0, 'cooked_rabbit'
    RABBIT_STEW = 'Rabbit stew', 413, 0, 'rabbit_stew'
    RABBITS_FOOT = "Rabbit's foot", 414, 0, 'rabbit_foot'
    RABBIT_HIDE = 'Rabbit hide', 415, 0, 'rabbit_hide'
    ARMOR_STAND = 'Armor stand', 416, 0, 'armor_stand'
    IRON_HORSE_ARMOR = 'Iron horse armor', 417, 0, 'iron_horse_armor'
    GOLD_HORSE_ARMOR = 'Gold horse armor', 418, 0, 'golden_horse_armor'
    DIAMOND_HORSE_ARMOR = 'Diamond horse armor', 419, 0, 'diamond_horse_armor'
    LEAD = 'Lead', 420, 0, 'lead'
    NAME_TAG = 'Name tag', 421, 0, 'name_tag'
    MINECART_COMMAND_BLOCK = 'Minecart (command block)', 422, 0, 'command_block_minecart'
    RAW_MUTTON = 'Raw mutton', 423, 0, 'mutton'
    COOKED_MUTTON = 'Cooked mutton', 424, 0, 'cooked_mutton'
    BANNER_BLACK = 'Banner (black)', 425, 0, 'banner'
    BANNER_RED = 'Banner (red)', 425, 1, 'banner:1'
    BANNER_GREEN = 'Banner (green)', 425, 2, 'banner:2'
    BANNER_BROWN = 'Banner (brown)', 425, 3, 'banner:3'
    BANNER_BLUE = 'Banner (blue)', 425, 4, 'banner:4'
    BANNER_PURPLE = 'Banner (purple)', 425, 5, 'banner:5'
    BANNER_CYAN = 'Banner (cyan)', 425, 6, 'banner:6'
    BANNER_LIGHT_GRAY = 'Banner (light gray)', 425, 7, 'banner:7'
    BANNER_GRAY = 'Banner (gray)', 425, 8, 'banner:8'
    BANNER_PINK = 'Banner (pink)', 425, 9, 'banner:9'
    BANNER_LIME = 'Banner (lime)', 425, 10, 'banner:10'
    BANNER_YELLOW = 'Banner (yellow)', 425, 11, 'banner:11'
    BANNER_LIGHT_BLUE = 'Banner (light blue)', 425, 12, 'banner:12'
    BANNER_MAGENTA = 'Banner (magenta)', 425, 13, 'banner:13'
    BANNER_ORANGE = 'Banner (orange)', 425, 14, 'banner:14'
    BANNER_WHITE = 'Banner (white)', 425, 15, 'banner:15'
    END_CRYSTAL = 'End crystal', 426, 0, 'end_crystal'
    WOODEN_DOOR_SPRUCE = 'Wooden door (spruce)', 427, 0, 'spruce_door'
    WOODEN_DOOR_BIRCH = 'Wooden door (birch)', 428, 0, 'birch_door'
    WOODEN_DOOR_JUNGLE = 'Wooden door (jungle)', 429, 0, 'jungle_door'
    WOODEN_DOOR_ACACIA = 'Wooden door (acacia)', 430, 0, 'acacia_door'
    WOODEN_DOOR_DARK_OAK = 'Wooden door (dark oak)', 431, 0, 'dark_oak_door'
    CHORUS_FRUIT = 'Chorus fruit', 432, 0, 'chorus_fruit'
    CHORUS_FRUIT_POPPED = 'Chorus fruit (popped)', 433, 0, 'chorus_fruit_popped'
    BEETROOT = 'Beetroot', 434, 0, 'beetroot'
    BEETROOT_SEEDS = 'Beetroot seeds', 435, 0, 'beetroot_seeds'
    BEETROOT_SOUP = 'Beetroot soup', 436, 0, 'beetroot_soup'
    DRAGONS_BREATH = "Dragon's breath", 437, 0, 'dragon_breath'
    ARROW_SPECTRAL = 'Arrow (spectral)', 439, 0, 'spectral_arrow'
    SHIELD = 'Shield', 442, 0, 'shield'
    ELYTRA = 'Elytra', 443, 0, 'elytra'
    TOTEM_OF_UNDYING = 'Totem of undying', 449, 0, 'totem'
    SHULKER_SHELL = 'Shulker shell', 450, 0, 'shulker_shell'
    MUSIC_DISK_13 = 'Music disk (13)', 2256, 0, 'record_13'
    MUSIC_DISK_CAT = 'Music disk (cat)', 2257, 0, 'record_cat'
    MUSIC_DISK_BLOCKS = 'Music disk (blocks)', 2258, 0, 'record_blocks'
    MUSIC_DISK_CHIRP = 'Music disk (chirp)', 2259, 0, 'record_chirp'
    MUSIC_DISK_FAR = 'Music disk (far)', 2260, 0, 'record_far'
    MUSIC_DISK_MALL = 'Music disk (mall)', 2261, 0, 'record_mall'
    MUSIC_DISK_MELLOHI = 'Music disk (mellohi)', 2262, 0, 'record_mellohi'
    MUSIC_DISK_STAL = 'Music disk (stal)', 2263, 0, 'record_stal'
    MUSIC_DISK_STRAD = 'Music disk (strad)', 2264, 0, 'record_strad'
    MUSIC_DISK_WARD = 'Music disk (ward)', 2265, 0, 'record_ward'
    MUSIC_DISK_11 = 'Music disk (11)', 2266, 0, 'record_11'
    MUSIC_DISK_WAIT = 'Music disk (wait)', 2267, 0, 'record_wait'
